# logger
import os, logging, time
logging.basicConfig()

DIGESTLEN = 5

class register:
	handlers = dict()
	def __init__(self, action):
		self._action = action
	def __call__(self, func):
		register.handlers[self._action] = func

def getLogger(name):
	logger = logging.getLogger(name)
	if "LOG_LEVEL" in os.environ:
		s = os.getenv('LOG_LEVEL')
		logger.setLevel(int(s) if s.isdigit() else getattr(logging, s))
	return logger

# generate sha1 digest
from hashlib import sha1, sha256, sha512
def digest(s):
	return sha512(s).digest()[:DIGESTLEN]

class Clock:
	def __init__(self):
		self._start = time.time()
	def elapsed(self):
		return time.time() - self._start



import time

__doc__ = """
simple class for measuring elapsed time.
just instantiate c = Clock() and keep calling c.elapsed() or c.split() to get the elapsed time since instantiation. 
"""

class Clock:
	def __init__(self):
		self._start = time.time()
	def elapsed(self):
		return time.time() - self._start
	split = elapsed



from setuptools import setup
from os.path import normpath, dirname, basename
from contextlib import contextmanager
import os, shutil, glob, sys, logging

logging.basicConfig(level=0)

log = logging.getLogger(sys.argv[0])

# setup.py: {CWD}/path/to/{project}/setup.py
# package directory: {CWD}/path/to/{project}/{package_dir}

# simple implementation of a directory stack
# http://stackoverflow.com/a/3012921/41957
@contextmanager
def dirstack(_path):
	old_path = os.getcwd()
	os.chdir(_path)
	yield
	os.chdir(old_path)

def detect_project_name():
	try:
	    log.debug(normpath(sys.argv[0]).split(os.sep))
	    name = normpath(sys.argv[0]).split(os.sep)[-2]
	except IndexError:
	    name = basename(os.path.abspath(os.getcwd()))

	# replace dash with underscore
	return name.replace('-', '_')

name = detect_project_name()
log.debug("project name = %s" %(name))

# Run in the same directory as the setup.py script
with dirstack(dirname(os.path.abspath(sys.argv[0]))):
	# if not os.path.isdir(name):
	#     log.info("Creating directory %s" % name)
	#     os.mkdir(name)

	# for x in glob.glob(
	# 	os.path.join(
	# 		os.path.dirname(normpath(sys.argv[0])), '*.py')
	# 	):
	#     print "Copy %s to %s" % (x, name)
	#     shutil.copy2(x, name)

	setup(name=name,
	      version='0.1.0',
			author='comsul',
			author_email='chnrxn+pypi@gmail.com',
	      packages=['wrappers'],
	      # modules=[], 
	      # install_requires=[]
	)



from cssselect.xpath import HTMLTranslator
from lxml import etree
from pyquery import PyQuery

__doc__ = """convenience wrapper around pyquery"""

def PQ(*args, **kw):
	"""wrapper for PyQuery to support mixed-case tag names"""
	return PyQuery(*args, css_translator=HTMLTranslator(xhtml=True), **kw)



import os, logging
logging.basicConfig()

__doc__ = """
reads LOG_LEVEL environment variable to set the log level for the logging module
e.g. LOG_LEVEL=10 python somescript.py
e.g. LOG_LEVEL=30 python somescript.py
e.g. LOG_LEVEL=DEBUG python somescript.py
e.g. LOG_LEVEL=WARNING python somescript.py
"""

def getLogger(name):
	logger = logging.getLogger(name)
	if "LOG_LEVEL" in os.environ:
		s = os.getenv('LOG_LEVEL')
		logger.setLevel(int(s) if s.isdigit() else getattr(logging, s))
	return logger
